@@ -7,6 +7,7 @@ from filelock import FileLock
 from multimodalsim_viewer.common.utils import (
     INPUT_DATA_DIRECTORY_PATH,
     NUMBER_OF_STATES_TO_SEND_AT_ONCE,
+    OUTPUT_DATA_DIRECTORY_PATH,
     SIMULATION_SAVE_FILE_SEPARATOR,
 )
 from multimodalsim_viewer.models.environment import VisualizedEnvironment
@@ -47,7 +48,7 @@ class SimulationVisualizationDataManager:  # pylint: disable=too-many-public-met
     @staticmethod
     def get_saved_simulations_directory_path() -> str:
         directory_path = os.path.join(
-            SimulationVisualizationDataManager.get_data_directory_path(),
+            SimulationVisualizationDataManager.get_output_data_directory_path(),
             SimulationVisualizationDataManager.__SAVED_SIMULATIONS_DIRECTORY_NAME,
         )
 
@@ -498,49 +499,19 @@ class SimulationVisualizationDataManager:  # pylint: disable=too-many-public-met
 
         return polylines, version
 
-    @staticmethod
-    def get_all_simulation_states(simulation_id: str) -> tuple[list[str], dict[list[str]]]:
-        states = []
-        updates = {}
-
-        sorted_states = SimulationVisualizationDataManager.get_sorted_states(simulation_id)
-
-        for update_index, timestamp in sorted_states:
-            file_path = SimulationVisualizationDataManager.get_saved_simulation_state_file_path(
-                simulation_id, update_index, timestamp
-            )
-
-            lock = FileLock(f"{file_path}.lock")
-
-            with lock:
-                with open(file_path, "r", encoding="utf-8") as file:
-                    state_data = file.readline()
-                    states.append(state_data)
-
-                    updates_data = file.readlines()
-                    current_state_updates = []
-                    for update_data in updates_data:
-                        current_state_updates.append(update_data)
-
-                    updates[update_index] = current_state_updates
-
-        return states, updates
-
     # MARK: +- Simulation Data
     @staticmethod
-    def get_data_directory_path() -> str:
-        current_file_path = os.path.abspath(__file__)
-        current_file_dir = os.path.dirname(current_file_path)
-        data_directory_path = os.path.join(current_file_dir, "..", "data")
+    def get_output_data_directory_path() -> str:
+        output_data_directory = OUTPUT_DATA_DIRECTORY_PATH
 
-        if not os.path.exists(data_directory_path):
-            os.makedirs(data_directory_path)
+        if not os.path.exists(output_data_directory):
+            os.makedirs(output_data_directory)
 
-        return data_directory_path
+        return output_data_directory
 
     @staticmethod
     def get_saved_logs_directory_path() -> str:
-        data_directory_path = SimulationVisualizationDataManager.get_data_directory_path()
+        data_directory_path = SimulationVisualizationDataManager.get_output_data_directory_path()
         saved_logs_directory_path = os.path.join(data_directory_path, "saved_logs")
 
         if not os.path.exists(saved_logs_directory_path):
